=============
Release notes
=============

.. include:: v2.1.2.rst
.. include:: v2.1.1.rst
.. include:: v2.1.0.rst
.. include:: v2.0.0.rst
.. include:: v1.4.1.rst
.. include:: v1.4.0.rst
.. include:: v1.3.0.rst
.. include:: v1.2.0.rst
.. include:: v1.1.0.rst
.. include:: v1.0.0.rst
.. include:: v0.9.9.rst
.. include:: v0.9.8.rst
.. include:: v0.9.7.rst
.. include:: v0.9.6.rst
.. include:: v0.9.5.rst
.. include:: v0.9.4.rst
.. include:: v0.9.3.rst
.. include:: v0.9.2.rst
